@@ -7,7 +7,7 @@
 #' @param .period The period size to roll over
 #' @param .align One of "center", "left" or "right".
 #' @param .partial Should the moving window be allowed to return partial (incomplete) windows
-#' instead of `NA` values. Set to FALSE by default, but can be switched to TRUE to remove `NA`'s.
+#' instead of `NA` values. Set to `FALSE` by default, but can be switched to `TRUE` to remove `NA`'s.
 #' @param .unlist If the function returns a single value each time it is called,
 #' use `.unlist = TRUE`. If the function returns more than one value, or a more
 #' complicated object (like a linear model), use `.unlist = FALSE` to create
@@ -75,11 +75,8 @@
 #'
 #' @examples
 #' library(dplyr)
-#' library(tidyr)
-#' library(stringr)
-#' library(timetk)
 #'
-#' FB <- FANG %>% filter(symbol == "FB")
+#' FB <- FANG %>% dplyr::filter(symbol == "FB")
 #'
 #'
 #' # --- ROLLING MEAN (SINGLE ARG EXAMPLE) ---
@@ -115,14 +112,13 @@
 #'     select(symbol, date, adjusted) %>%
 #'     tk_augment_slidify(
 #'         adjusted, .period = 5:10, .f = mean, .align = "right",
-#'         .names = str_c("MA_", 5:10)
+#'         .names = stringr::str_c("MA_", 5:10)
 #'     )
 #'
 #' # --- GROUPS AND ROLLING ----
 #'
 #' # One of the most powerful things about this is that it works with
 #' # groups since `mutate` is being used
-#' data(FANG)
 #'
 #' mean_roll_3 <- slidify(mean, .period = 3, .align = "right")
 #'
@@ -176,7 +172,7 @@
 #' lm_roll <- slidify(~lm(.x ~ .y), .period = 90, .unlist = FALSE, .align = "right")
 #'
 #' FB %>%
-#'     drop_na() %>%
+#'     tidyr::drop_na() %>%
 #'     mutate(numeric_date = as.numeric(date)) %>%
 #'     mutate(rolling_lm = lm_roll(adjusted, numeric_date)) %>%
 #'     filter(!is.na(rolling_lm))
@@ -185,7 +181,6 @@
 #'
 #'
 #' @export
-#'
 slidify <- function(.f, .period = 1,
                     .align = c("center", "left", "right"),
                     .partial = FALSE,
@@ -245,26 +240,30 @@ slider_2 <- function(..., .slider_fun, .f, .period, .align, .partial, .unlist) {
 check_dots <- function(x, .period) {
 
     # The user must have passed something to be passed on to .f
-    assertthat::assert_that(length(x) > 0,
-                            msg = "At least 1 data argument must be supplied to be
-                          passed on to the rolling function")
+    if (length(x) == 0) {
+        stop("At least 1 data argument must be supplied to be
+                          passed on to the rolling function", call. = FALSE)
+    }
 
 
     # The .period must be smaller than the length of the data
-    assertthat::assert_that(.period <= length(x[[1]]),
-                            msg = "Cannot roll apply with a .period larger than the
+    if (any(.period > length(x[[1]]))) {
+        stop(call. = FALSE, "Cannot roll apply with a .period larger than the
                           length of the data")
+    }
 
 
     # Length of every element of .dots should be the same
     # Only data used in the rolling should be in .dots
     # Optional args should be specified in the slidify call
-    for(i in 1:length(x)) {
-        assertthat::assert_that(length(x[[i]]) == length(x[[1]]),
-                                msg = "Arguments supplied to the rolling version
+    lens <- lengths(x)
+    n_distinct_length_x <- length(unique(lens))
+    if (n_distinct_length_x != 1) {
+        stop(call. = FALSE, "Arguments supplied to the rolling version
                             of the function should be data of the same length.
                             Optional arguments should be specified when creating
                             the rolling version with `slidify()`")
     }
+    TRUE
 }
 
