@@ -63,7 +63,7 @@ test_that("tk_make_future_timeseries(datetime) test returns correct format.", {
         length_out = 10
     ) %>%
         tk_make_future_timeseries(length_out = 3)
-    expectation <- c("2011-11-15", "2011-12-15", "2012-01-15") %>% ymd()
+    expectation <- c("2011-11-15", "2011-12-15", "2012-01-15") %>% lubridate::ymd()
     expect_equal(test, expectation)
 
 
@@ -74,7 +74,7 @@ test_that("tk_make_future_timeseries(datetime) test returns correct format.", {
         length_out = 10
     )  %>%
         tk_make_future_timeseries(length_out = 4)
-    expectation <- c("2011-11-30", "2011-12-31", "2012-01-31", "2012-02-29") %>% ymd()
+    expectation <- c("2011-11-30", "2011-12-31", "2012-01-31", "2012-02-29") %>% lubridate::ymd()
     expect_equal(test, expectation)
 
 })
@@ -93,17 +93,17 @@ test_that("tk_make_future_timeseries(date) test returns correct format.", {
     # No skip values, inspect_weekdays = FALSE
     test_1 <- tk_make_future_timeseries(test_date, length_out = 3, skip_values = NULL, inspect_weekdays = FALSE)
     test_2 <- tk_make_future_timeseries(test_date, length_out = "3 days", skip_values = NULL, inspect_weekdays = FALSE)
-    expectation <- c("2016-12-31", "2017-01-01", "2017-01-02") %>% ymd()
+    expectation <- c("2016-12-31", "2017-01-01", "2017-01-02") %>% lubridate::ymd()
     expect_identical(test_1, test_2, expectation)
 
     # No skip values, inspect_weekdays = TRUE
     test_1 <- tk_make_future_timeseries(test_date, length_out = 3, skip_values = NULL, inspect_weekdays = TRUE)
     test_2 <- tk_make_future_timeseries(test_date, length_out = "5 days", skip_values = NULL, inspect_weekdays = TRUE)
-    expectation <- c("2017-01-02", "2017-01-03", "2017-01-04") %>% ymd()
+    expectation <- c("2017-01-02", "2017-01-03", "2017-01-04") %>% lubridate::ymd()
     expect_identical(test_1, test_2, expectation)
 
     # Skip values, inspect_weekdays = TRUE
-    holidays <- c("2017-01-03", "2017-01-04") %>% ymd()
+    holidays <- c("2017-01-03", "2017-01-04") %>% lubridate::ymd()
     test <- tk_make_future_timeseries(test_date, length_out = 8, skip_values = holidays, inspect_weekdays = TRUE)
     expectation <- c("2017-01-02", "2017-01-05", "2017-01-06", "2017-01-09", "2017-01-10", "2017-01-11", "2017-01-12", "2017-01-13") %>%
         ymd()
@@ -140,38 +140,38 @@ test_that("tk_make_future_timeseries(date) test returns correct format.", {
     # WEEKLY SCALE ----
 
     # No skip
-    test_date   <- c("2017-01-01", "2017-01-08") %>% ymd()
-    expectation <- c("2017-01-15", "2017-01-22") %>% ymd()
+    test_date   <- c("2017-01-01", "2017-01-08") %>% lubridate::ymd()
+    expectation <- c("2017-01-15", "2017-01-22") %>% lubridate::ymd()
     test_1 <- tk_make_future_timeseries(test_date, length_out = 2)
     test_2 <- tk_make_future_timeseries(test_date, length_out = "2 weeks")
     expect_identical(test_1, test_2, expectation)
 
     # With skip
-    test_date    <- c("2017-01-01", "2017-01-08") %>% ymd()
-    skip_values  <- c("2017-01-22") %>% ymd()
-    expectation  <- c("2017-01-15", "2017-01-29") %>% ymd()
+    test_date    <- c("2017-01-01", "2017-01-08") %>% lubridate::ymd()
+    skip_values  <- c("2017-01-22") %>% lubridate::ymd()
+    expectation  <- c("2017-01-15", "2017-01-29") %>% lubridate::ymd()
     test <- tk_make_future_timeseries(test_date, length_out = 2, skip_values = skip_values)
     expect_equal(test, expectation)
 
     # With insert
-    test_date   <- c("2017-01-01", "2017-01-08") %>% ymd()
-    insert      <- c("2017-01-29") %>% ymd()
-    expectation <- c("2017-01-15", "2017-01-22") %>% ymd()
+    test_date   <- c("2017-01-01", "2017-01-08") %>% lubridate::ymd()
+    insert      <- c("2017-01-29") %>% lubridate::ymd()
+    expectation <- c("2017-01-15", "2017-01-22") %>% lubridate::ymd()
     expect_message(test <- tk_make_future_timeseries(test_date, length_out = 2, insert_values = insert))
     expect_equal(test, expectation)
 
     # With insert / Message
-    test_date   <- c("2017-01-01", "2017-01-08") %>% ymd()
-    insert      <- c("2017-01-22") %>% ymd()
-    expectation <- c("2017-01-15", "2017-01-22") %>% ymd()
+    test_date   <- c("2017-01-01", "2017-01-08") %>% lubridate::ymd()
+    insert      <- c("2017-01-22") %>% lubridate::ymd()
+    expectation <- c("2017-01-15", "2017-01-22") %>% lubridate::ymd()
     expect_message(test <- tk_make_future_timeseries(test_date, length_out = 2, insert_values = insert))
     expect_equal(expectation, test)
 
     # MONTHLY SCALE ----
 
     # No skip
-    idx   <- c("2017-01-15", "2017-02-15") %>% ymd()
-    expectation <- c("2017-03-15", "2017-04-15") %>% ymd()
+    idx   <- c("2017-01-15", "2017-02-15") %>% lubridate::ymd()
+    expectation <- c("2017-03-15", "2017-04-15") %>% lubridate::ymd()
     test_1 <- tk_make_future_timeseries(idx, length_out = 2)
     test_2 <- tk_make_future_timeseries(idx, length_out = "2 months")
 
@@ -179,34 +179,34 @@ test_that("tk_make_future_timeseries(date) test returns correct format.", {
     expect_identical(test_2, expectation)
 
     # With skip
-    test_date   <- c("2017-01-01", "2017-02-01") %>% ymd()
-    skip_values <- c("2017-03-01") %>% ymd()
-    expectation <- c("2017-04-01", "2017-05-01") %>% ymd()
+    test_date   <- c("2017-01-01", "2017-02-01") %>% lubridate::ymd()
+    skip_values <- c("2017-03-01") %>% lubridate::ymd()
+    expectation <- c("2017-04-01", "2017-05-01") %>% lubridate::ymd()
     expect_equal(tk_make_future_timeseries(test_date, length_out = 2, skip_values = skip_values),
                  expectation)
 
     # With insert
-    test_date   <- c("2017-01-01", "2017-02-01") %>% ymd()
-    insert      <- c("2017-06-01") %>% ymd()
-    expectation <- c("2017-03-01", "2017-04-01") %>% ymd()
+    test_date   <- c("2017-01-01", "2017-02-01") %>% lubridate::ymd()
+    insert      <- c("2017-06-01") %>% lubridate::ymd()
+    expectation <- c("2017-03-01", "2017-04-01") %>% lubridate::ymd()
     expect_message(test <- tk_make_future_timeseries(test_date, length_out = 2, insert_values = insert))
     expect_equal(test, expectation)
 
     # QUARTERLY SCALE ----
 
     # No skip
-    test_date   <- c("2017-01-15", "2017-04-15") %>% ymd()
+    test_date   <- c("2017-01-15", "2017-04-15") %>% lubridate::ymd()
     test_1 <- tk_make_future_timeseries(test_date, length_out = 2)
     test_2 <- tk_make_future_timeseries(test_date, length_out = "6 months")
-    expectation <- c("2017-07-15", "2017-10-15") %>% ymd()
+    expectation <- c("2017-07-15", "2017-10-15") %>% lubridate::ymd()
 
     expect_identical(test_1, expectation)
     expect_identical(test_2, expectation)
 
     # With skip
-    test_date    <- c("2017-01-01", "2017-04-01") %>% ymd()
-    skip_values  <- c("2017-10-01") %>% ymd()
-    expectation  <- c("2017-07-01", "2018-01-01") %>% ymd()
+    test_date    <- c("2017-01-01", "2017-04-01") %>% lubridate::ymd()
+    skip_values  <- c("2017-10-01") %>% lubridate::ymd()
+    expectation  <- c("2017-07-01", "2018-01-01") %>% lubridate::ymd()
     test <- tk_make_future_timeseries(test_date, length_out = 2, skip_values = skip_values)
     expect_equal(test, expectation)
 
@@ -215,24 +215,24 @@ test_that("tk_make_future_timeseries(date) test returns correct format.", {
     # YEARLY SCALE ----
 
     # No skip
-    test_date   <- c("2017-06-30", "2018-06-30") %>% ymd()
-    expectation <- c("2019-06-30", "2020-06-30") %>% ymd()
+    test_date   <- c("2017-06-30", "2018-06-30") %>% lubridate::ymd()
+    expectation <- c("2019-06-30", "2020-06-30") %>% lubridate::ymd()
     test_1 <- tk_make_future_timeseries(test_date, length_out = 2)
     test_2 <- tk_make_future_timeseries(test_date, length_out = "2 years")
     expect_identical(test_1, test_2, expectation)
 
     # With skip
-    test_date   <- c("2017-04-01", "2018-04-01") %>% ymd()
-    skip_values  <- c("2019-04-01") %>% ymd()
-    expectation <- c("2020-04-01", "2021-04-01") %>% ymd()
+    test_date   <- c("2017-04-01", "2018-04-01") %>% lubridate::ymd()
+    skip_values  <- c("2019-04-01") %>% lubridate::ymd()
+    expectation <- c("2020-04-01", "2021-04-01") %>% lubridate::ymd()
     test <- tk_make_future_timeseries(test_date, length_out = 2, skip_values = skip_values)
     expect_equal(test, expectation)
 
     # 1.5X YEARLY SCALE ----
 
     # No skip
-    test_date   <- c("2017-07-01", "2019-01-01") %>% ymd()
-    expectation <- c("2020-07-01", "2022-01-01") %>% ymd()
+    test_date   <- c("2017-07-01", "2019-01-01") %>% lubridate::ymd()
+    expectation <- c("2020-07-01", "2022-01-01") %>% lubridate::ymd()
     test_1 <- tk_make_future_timeseries(test_date, length_out = 2)
     test_2 <- tk_make_future_timeseries(test_date, length_out = "3 years")
     expect_identical(test_1, test_2, expectation)
@@ -250,23 +250,23 @@ test_that("tk_make_future_timeseries(yearmon) test returns correct format.", {
 
     test_yearmon <- c("2016-01",
                       "2016-02",
-                      "2016-03") %>% as.yearmon()
+                      "2016-03") %>% zoo::as.yearmon()
 
     # No skip values
     test <- tk_make_future_timeseries(test_yearmon, length_out = "3 months")
     expectation <- c("2016-04", "2016-05", "2016-06") %>%
-        as.yearmon()
+        zoo::as.yearmon()
     expect_equal(test, expectation)
 
     # Skip values
-    skip <- as.yearmon("2016-05")
+    skip <- zoo::as.yearmon("2016-05")
     test <- tk_make_future_timeseries(test_yearmon, length_out = 2, skip_values = skip)
     expectation <- c("2016-04", "2016-06")  %>%
-        as.yearmon()
+        zoo::as.yearmon()
     expect_equal(test, expectation)
 
     # Test when skip values are not within future index
-    skip <- as.yearmon(c("2016-10", "2016-11"))
+    skip <- zoo::as.yearmon(c("2016-10", "2016-11"))
     expect_message(tk_make_future_timeseries(test_yearmon, length_out = 3, skip_values = skip))
 
     # Inspect validation of skip_values
@@ -274,10 +274,10 @@ test_that("tk_make_future_timeseries(yearmon) test returns correct format.", {
     expect_equal(test, NA)
 
     # insert values
-    insert <- as.yearmon(c("2017-10", "2017-11"))
+    insert <- zoo::as.yearmon(c("2017-10", "2017-11"))
     test <- tk_make_future_timeseries(test_yearmon, length_out = 3, insert_values = insert)
     expectation <- c("2016-04", "2016-05", "2016-06")  %>%
-        as.yearmon()
+        zoo::as.yearmon()
     expect_equal(test, expectation)
 
 })
@@ -290,26 +290,26 @@ test_that("tk_make_future_timeseries(yearqtr) test returns correct format.", {
     test_yearqtr <- c("2016 Q1",
                       "2016 Q2",
                       "2016 Q3",
-                      "2016 Q4") %>% as.yearqtr()
+                      "2016 Q4") %>% zoo::as.yearqtr()
 
     # No skip values
     test <- tk_make_future_timeseries(test_yearqtr, length_out = "1 year")
     expectation <- c("2017 Q1", "2017 Q2", "2017 Q3", "2017 Q4") %>%
-        as.yearqtr()
+        zoo::as.yearqtr()
     expect_equal(test, expectation)
 
     # Skip values
-    skip <- as.yearqtr("2017 Q1")
+    skip <- zoo::as.yearqtr("2017 Q1")
     test <- tk_make_future_timeseries(test_yearqtr, length_out = 4, skip_values = skip)
     expectation <- c("2017 Q2", "2017 Q3", "2017 Q4", "2018 Q1")  %>%
-        as.yearqtr()
+        zoo::as.yearqtr()
     expect_equal(test, expectation)
 
     # Test when skip values are not within future index
-    skip <- as.yearqtr(c("2017 Q1", "2018 Q2"))
+    skip <- zoo::as.yearqtr(c("2017 Q1", "2018 Q2"))
     expect_message(test <- tk_make_future_timeseries(test_yearqtr, length_out = 4, skip_values = skip))
     expectation <- c("2017 Q2", "2017 Q3", "2017 Q4", "2018 Q1")  %>%
-        as.yearqtr()
+        zoo::as.yearqtr()
     expect_equal(test, expectation)
 
     # Inspect validation of skip_values
@@ -402,10 +402,10 @@ test_that("tk_make_future_timeseries(predict_every_three) test returns correct f
 
 test_that("tk_make_future_timeseries(): End of Month", {
 
-    series <- c("2011-01-31", "2011-04-30", "2011-07-31", "2011-10-31") %>% ymd()
+    series <- c("2011-01-31", "2011-04-30", "2011-07-31", "2011-10-31") %>% lubridate::ymd()
 
     test <- tk_make_future_timeseries(series, length_out = 4)
-    expectation <- c("2012-01-31", "2012-04-30", "2012-07-31", "2012-10-31") %>% ymd()
+    expectation <- c("2012-01-31", "2012-04-30", "2012-07-31", "2012-10-31") %>% lubridate::ymd()
 
     expect_equal(test, expectation)
 
